;; Generated package description from embark.el  -*- no-byte-compile: t -*-
(define-package "embark" "1.0" "Conveniently act on minibuffer completions" '((emacs "27.1") (compat "29.1.4.0")) :commit "47b0c75d4bf4f72a7af839667c877c80bd493cdb" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
